@@ -16,7 +16,7 @@
  */
 
 #include <QDir>
-#ifdef Q_OS_SYMBIAN
+#ifdef SYMBIAN_OS
 #include <QCoreApplication>
 #endif
 #include "selectionmodels.h"
@@ -56,6 +56,16 @@ QVariantMap SelectionModel::get(int row) const {
     return item;
 }
 
+int SelectionModel::match(const QString &role, const QVariant &value) const {
+    for (int i = 0; i < this->rowCount(); i++) {
+        if (this->data(this->index(i, 0), m_roleNames.key(role.toUtf8())) == value) {
+            return i;
+        }
+    }
+    
+    return -1;
+}
+
 void SelectionModel::addItem(const QString &name, const QVariant &value) {
     QStandardItem *item = new QStandardItem(name);
     item->setData(value);
@@ -67,11 +77,16 @@ void SelectionModel::addItem(const QString &name, const QVariant &value) {
 ScreenOrientationModel::ScreenOrientationModel(QObject *parent) :
     SelectionModel(parent)
 {
-    this->addItem(tr("Automatic"), ScreenOrientation::Automatic);
-    this->addItem(tr("Portrait"), ScreenOrientation::LockPortrait);
-    this->addItem(tr("Landscape"), ScreenOrientation::LockLandscape);
-
-    emit countChanged(this->rowCount());
+#ifdef Q_WS_MAEMO_5
+    this->addItem(tr("Automatic"), Qt::WA_Maemo5AutoOrientation);
+    this->addItem(tr("Portrait"), Qt::WA_Maemo5PortraitOrientation);
+    this->addItem(tr("Landscape"), Qt::WA_Maemo5LandscapeOrientation);
+#else
+    this->addItem(tr("Automatic"), 0);
+    this->addItem(tr("Portrait"), 1);
+    this->addItem(tr("Landscape"), 2);
+#endif
+    emit countChanged();
 }
 
 LanguageModel::LanguageModel(QObject *parent) :
@@ -263,7 +278,7 @@ LanguageModel::LanguageModel(QObject *parent) :
     languages.insert(tr("Zhuang"), "za");
     languages.insert(tr("Zulu"), "zu");
 
-#ifdef Q_OS_SYMBIAN
+#ifdef SYMBIAN_OS
     QDir dir(QCoreApplication::applicationDirPath());
     dir.cd("translations");
 #else
@@ -275,7 +290,7 @@ LanguageModel::LanguageModel(QObject *parent) :
         this->addItem(languages.key(code), code);
     }
 
-    emit countChanged(this->rowCount());
+    emit countChanged();
 }
 
 #ifdef MEEGO_EDITION_HARMATTAN
@@ -301,50 +316,6 @@ ActiveColorModel::ActiveColorModel(QObject *parent) :
     this->addItem("#ed970c", "#ed970c");
     this->addItem("#f2b317", "#f2b317");
 
-    emit countChanged(this->rowCount());
+    emit countChanged();
 }
 #endif
-
-NetworkProxyTypeModel::NetworkProxyTypeModel(QObject *parent) :
-    SelectionModel(parent)
-{
-    this->addItem(QString("HTTP"), NetworkProxyType::HttpProxy);
-    this->addItem(QString("HTTP %1").arg(tr("caching")), NetworkProxyType::HttpCachingProxy);
-    this->addItem(QString("SOCKS5"), NetworkProxyType::Socks5Proxy);
-
-    emit countChanged(this->rowCount());
-}
-
-MediaPlayerModel::MediaPlayerModel(QObject *parent) :
-    SelectionModel(parent)
-{
-    this->addItem(tr("cuteRadio"), "cuteradio");
-#ifdef Q_OS_LINUX
-    this->addItem(tr("Custom command"), "other");
-
-    QFileInfo info("/usr/bin/kmplayer");
-
-    if (info.exists()) {
-        this->addItem("KMPlayer", "kmplayer");
-    }
-    else {
-        info.setFile("/opt/kmplayer/bin/kmplayer");
-
-        if (info.exists()) {
-            this->addItem("KMPlayer", "kmplayer");
-        }
-    }
-#endif
-    this->addItem(tr("Media Player"), "mediaplayer");
-
-    emit countChanged(this->rowCount());
-}
-
-StationTypeModel::StationTypeModel(QObject *parent) :
-    SelectionModel(parent)
-{
-    this->addItem(tr("Stations"), Stations::Radio);
-    this->addItem(tr("Podcasts"), Stations::Podcast);
-
-    emit countChanged(this->rowCount());
-}
