@@ -27,13 +27,6 @@ class Utils : public QObject
 {
     Q_OBJECT
 
-    Q_PROPERTY(QString versionNumber
-               READ versionNumber
-               CONSTANT)
-    Q_PROPERTY(QString logoPath
-               READ logoPath
-               CONSTANT)
-
 public:
     explicit Utils(QObject *parent = 0);
     ~Utils();
@@ -42,16 +35,11 @@ public:
     Q_INVOKABLE static QString durationFromMSecs(int msecs);
     Q_INVOKABLE static QString fileSizeFromPath(const QString &filePath);
     Q_INVOKABLE static QString fileSizeFromBytes(double bytes);
-    Q_INVOKABLE static QString dateFromSecs(qint64 secs, bool showTime = true);
-    Q_INVOKABLE static QString dateFromMSecs(qint64 msecs, bool showTime = true);
-    Q_INVOKABLE static QString localDateTimeFromString(const QString &dateTimeString, Qt::DateFormat = Qt::ISODate);
-    Q_INVOKABLE static QString base64Id(const QString &artist, const QString &title);
     Q_INVOKABLE static QString httpErrorString(int errorCode);
     Q_INVOKABLE static bool urlIsPlaylist(const QUrl &url);
     Q_INVOKABLE static QString capitalise(const QString &string);
+    Q_INVOKABLE static QString buildString(const QString &str, const QStringList &args);
     Q_INVOKABLE static void log(const QString &filePath, const QByteArray &message);
-    Q_INVOKABLE static QString versionNumber();
-    Q_INVOKABLE static QString logoPath();
 };
 
-#endif // UTILS_H
+#endif
